# Changelog

## 0.4.1 (2022-01-09)

Switch to setup.cfg and a PEP517-build.

## 0.4.0 (2021-09-18)

Update to the README as well as test, pre-commit and CI configuration.

## 0.3 (2018-12-15)

Fixes #2, persisting self.pad. Version bump.

## 0.2 (2018-05-13)

Readme and setup.py updates, changed the name and description, bump to 0.2.